@@ -12,6 +12,9 @@ from .risk import *
 from .strategy import *
 from .util import *
 from .backtest_engine import BacktestEngine
+from .trading_env import TradingEnv
+from .portfolio_env import PortfolioEnv
+from .version import VERSION as __version__
 
 # https://docs.python-guide.org/writing/logging/
 import logging
