@@ -54,8 +54,9 @@ class MainWindow(QtWidgets.QMainWindow):
         self.account_window = None
         self.strategy_window = None
 
-        self._msg_events_engine = LiveEventEngine()  # msg engine
         self._tick_events_engine = LiveEventEngine()  # tick data engine
+        # self._msg_events_engine = LiveEventEngine()  # msg engine
+        self._msg_events_engine = self._tick_events_engine      # no race
         self._broker = InteractiveBrokers(self._msg_events_engine, self._tick_events_engine, self._config['account'])
         self._position_manager = PositionManager('Global')      # global position manager
         self._position_manager.set_instrument_meta(self.instrument_meta)
@@ -92,8 +93,8 @@ class MainWindow(QtWidgets.QMainWindow):
         self._msg_events_engine.register_handler(EventType.LOG, self.log_window.msg_signal.emit)
 
         ## start
-        self._msg_events_engine.start()
         self._tick_events_engine.start()
+        # self._msg_events_engine.start()
 
         self.connect_to_broker()
 
@@ -253,8 +254,8 @@ class MainWindow(QtWidgets.QMainWindow):
     def closeEvent(self, a0: QtGui.QCloseEvent):
         _logger.info('closing main window')
         self.disconnect_from_broker()
-        self._msg_events_engine.stop()
         self._tick_events_engine.stop()
+        # self._msg_events_engine.stop()
 
     def _tick_event_handler(self, tick_event):
         self._current_time = tick_event.timestamp
